## Copyright (C) 2015 Oscar Monerris Belda
## 
## This program is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program.  If not, see <http://www.gnu.org/licenses/>.

## -*- texinfo -*- 
## @deftypefn {Function File} {@var{xwrap} =} wrapTo180 (@var{x})
##
## Wraps x into the -180 to 180 interval
##
## @var{x}: angle in degrees (single value or vector)
##
## @example
## -160 = wrapTo180 (200)
## @end example
##
## @seealso{unwrap, wrapToPi}
## @end deftypefn

function xwrap = wrapTo180 (x)
  xwrap = mod (x + 180, 360) - 180;
endfunction

%!test
%! x = -800:0.1:800;
%! xw = wrapTo180 (x);
%! assert (sind (x), sind (xw), 16 * eps)
%! assert (cosd (x), cosd (xw), 16 * eps)
%! assert (! any (xw < -180))
%! assert (! any (xw > 180))
